Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type CarPrice ¶
CarPrice holds name and price of a car
func GetForeignCarsPrices ¶
GetForeignCarsPrices return a slice of car prices for foreign cars
func GetIranianCarsPrices ¶
GetIranianCarsPrices return a slice of car prices for Iranian cars
Click to show internal directories.
Click to hide internal directories.